import os


try:
    import ubuntu_website
    uw_import = True
except ImportError:
    print "You need the ubuntu_website theme"
    uw_import = False


PROJECT_PATH = os.path.dirname(os.path.abspath(__file__))


DEBUG = True
TEMPLATE_DEBUG = DEBUG
STATIC_SERVE = DEBUG


ADMINS = (
    ('Dave Walker', 'DaveWalker@ubuntu.com'),
)

MANAGERS = ADMINS

DATABASE_ENGINE = 'sqlite3'           # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'oracle'.
DATABASE_NAME = 'awstrial.db'             # Or path to database file if using sqlite3.

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# If running in a Windows environment this must be set to the same as your
# system time zone.
TIME_ZONE = 'Europe/London'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'en-gb'

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# Absolute path to the directory that holds media.
# Example: "/home/media/media.lawrence.com/"
MEDIA_ROOT = os.path.join(PROJECT_PATH, 'media')

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash if there is a path component (optional in other cases).
# Examples: "http://media.lawrence.com", "http://example.com/media/"
MEDIA_URL = '/media/'

# URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
# trailing slash.
# Examples: "http://foo.com/media/", "/media/".
ADMIN_MEDIA_PREFIX = '/media/admin/'

# Make this unique, and don't share it with anybody.
SECRET_KEY = '!=xjt)_6e%s^3v9#wb@1%$67quslp2%cnih9g7v24movrl0lup'

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.load_template_source',
    'django.template.loaders.app_directories.load_template_source',
)


TEMPLATE_CONTEXT_PROCESSORS = (
    "django.core.context_processors.auth",
    "django.core.context_processors.debug",
    "django.core.context_processors.i18n",
    "django.core.context_processors.media",
    "django.core.context_processors.request",
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
)

AUTHENTICATION_BACKENDS = (
            'django_openid_auth.auth.OpenIDBackend',
            'django.contrib.auth.backends.ModelBackend',
)


ROOT_URLCONF = 'awstrial.urls'

TEMPLATE_DIRS = (
    os.path.join(PROJECT_PATH, 'templates'),
    os.path.join(PROJECT_PATH, 'templates/cloud-init'),
)

if uw_import:
    TEMPLATE_CONTEXT_PROCESSORS += (
        "ubuntu_website.media_processor",
        "ubuntu_website.popup_check",
    )
    TEMPLATE_DIRS += (
        ubuntu_website.TEMPLATE_DIR,
    )



INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.admin',
    'django_openid_auth',
    'awstrial.trial',
)

OPENID_CREATE_USERS = True
OPENID_UPDATE_DETAILS_FROM_SREG = True
LOGIN_URL = '/openid/login/'
LOGIN_REDIRECT_URL = '/'
OPENID_SSO_SERVER_URL = 'https://login.launchpad.net/'
#OPENID_USE_AS_ADMIN_LOGIN = True

# from http://uec-images.ubuntu.com/query/maverick/server/daily.current.txt

## ami ids for Maverick RC (2010928.4) i386 ebs
#REGION2AMI = {
#  'ap-southeast-1' : 'ami-f61866a4',
#  'eu-west-1' : 'ami-926d58e6',
#  'us-east-1' : 'ami-d853a6b1',
#  'us-west-1' : 'ami-5817471d',
#}
# ami ids for Maverick RC (2010928.4) i386 instance-store
REGION2AMI = {
  'ap-southeast-1' : 'ami-ce18669c',
  'eu-west-1' : 'ami-ca6d58be',
  'us-east-1' : 'ami-1650a57f',
  'us-west-1' : 'ami-46174703',
}

# instance_type: the type of instance to launch
# Note, t1.micro can only be run on EBS store instances.
INSTANCE_TYPE="m1.small"
# instance_key_name must exist in each region (euca-describe-keypairs)
INSTANCE_KEY_NAME="cloud42"
# security_groups must exist in each region (euca-describe-groups)
INSTANCE_SECURITY_GROUPS=("cloud42",)

LIFETIME = 60 * 55;
# wait this long after reservation start before bothering with console
CONSOLE_WAIT = 240;

BASE_URL = "http://example.com"

configs = [
    { 'name': 'default', 'description': 'Base System',
      'template': None, 'info_tmpl': 'base-info' },
    { 'name': 'wordpress', 'description': 'Wordpress System',
      'template': 'cc-wordpress', 'info_tmpl': 'cc-wordpress-info' },
    { 'name': 'moinmoin', 'description': 'MoinMoin Wiki',
       'template': 'cc-moinmoin', 'info_tmpl': 'cc-moinmoin-info' },
]

import logging
try:
  from local_settings import *
except ImportError:
  logging.warning("No local_settings.py were found. See INSTALL for instructions.")

# vi: ts=4 expandtab
