# vi: ts=4 expandtab
from django.http import HttpResponse
from django.http import HttpResponseRedirect
from django.shortcuts import render_to_response
from trial.models import Instances
from django.template import RequestContext, Context
from django import forms
from django.forms.widgets import *
#from django.core.mail import send_mail, BadHeaderError
from django.contrib.auth.decorators import login_required
from django.contrib.auth import logout

from trial.models import Campaign, Instances, Feedback
from django.contrib.auth.models import User
from trial.forms import FeedbackForm


from awstrial.trial import ec2_helper, lp_helper, util
from awstrial import settings



def index(request):
    """ Main landing Page """
    campaign = Campaign.objects.filter(active=True)

    context = {
        'campaign': campaign,
    }

    return render_to_response("index.html", context,
                              context_instance=RequestContext(request))




@login_required
def start(request,campaign):
    """ Check the auth'd user has an ssh key """
    if lp_helper.has_sshkey(request.user):
        return HttpResponseRedirect("/%s/run/" % campaign)
    else:
        logout(request)
        return HttpResponseRedirect("https://help.launchpad.net/YourAccount/CreatingAnSSHKeyPair") # redirect to page advising they need to add a key



@login_required
def run_instance(request,campaign):
    current_campaign=Campaign.objects.get(name=campaign)
    # First, check they haven't already used their instance.
    if not Instances.objects.filter(campaign__name=campaign,owner=request.user): 
        # Now Check the campaign is running and has avaliability left.
        if current_campaign.remaining() and (current_campaign.active):
            # a = disclaimer box
            a = request.POST.get('a', '')
            if a:
                #try:
                region = request.POST.get('region',None)
                config = request.POST.get('config', '')
                byobu = request.POST.get('byobu','')
                ec2_helper.runit(campaign,lpid=request.user, region=region, config=config, byobu=byobu)
                #send_mail(subject, message, from_email, ['davewalker@ubuntu.com'])
                #except BadHeaderError:   #Example of basic error handling
                #	return HttpResponse('Invalid header found.')
                return HttpResponseRedirect("/%s/instance_info/" % campaign)
            return render_to_response('contacts.html', {'form': Instances(), 'settings': settings })
        else:
            return HttpResponseRedirect("/") # redirect to main page, campaign exceeded.
	
    #return render_to_response('contacts.html', {'form': Instances()},
    #			RequestContext(request))
    return HttpResponseRedirect("/%s/instance_info/" % campaign)


@login_required
def reserved_instance(request,campaign):
    """ Instance is now reserved """
    return render_to_response('thankyou.html')

@login_required
def info_instance(request,campaign):
    """ Return details about Instance """
    instance = Instances.objects.get(owner=request.user)
    instcfg = util.find_config(instance.config,settings.configs)
    context = {
        'instance': instance,
        'config': instcfg,
    }

    return render_to_response('instance.html', context,
                              context_instance=RequestContext(request))

def feedback(request):
    form=FeedbackForm(request.POST)
    if form.is_valid():
        form.save()
    entries=Feedback.objects.all()
    templates={'form' : form, 'feedback' : feedback}
    return render_to_response('feedback.html', templates)

def logout_view(request):
    logout(request)
    return HttpResponseRedirect('/')

